# Arduino COM Port finder by GWiz

import tkinter as tk
import os
import subprocess
import shlex
import sys

# Create the main window
window = tk.Tk()
window.title('COM Port Finder')  # Set the title of the window
window.geometry('600x400')  # Set the size of the window

# Create the Four text boxes and their labels
label1 = tk.Label(window, text='Arduino Handshake Message:', font=('Arial', 16), fg='red')
label1.pack(pady=2)
entry1 = tk.Entry(window, font=('Arial', 16), width=40)
entry1.insert(0, 'Handshake')
entry1.pack(pady=10)

label2 = tk.Label(window, text='Arduino Found Message:', font=('Arial', 16), fg='red')
label2.pack(pady=2)
entry2 = tk.Entry(window, font=('Arial', 16), width=40)
entry2.insert(0, 'Confirmed - Arduino found on port:')
entry2.pack(pady=10)

label3 = tk.Label(window, text='Arduino not found Message:', font=('Arial', 16), fg='red')
label3.pack(pady=2)
entry3 = tk.Entry(window, font=('Arial', 16), width=40)
entry3.insert(0, 'Arduino not detected on any COM Ports!')
entry3.pack(pady=10)

label4 = tk.Label(window, text='BAUD Rate/Bits per Sec:', font=('Arial', 16), fg='red')
label4.pack(pady=2)
entry4 = tk.Entry(window, font=('Arial', 16), width=40)
entry4.insert(0, '57600')
entry4.pack(pady=10)

def create_exe():

    # Get the text entered in the four text boxes
    title1 = entry1.get()
    title2 = entry2.get()
    title3 = entry3.get()
    title4 = entry4.get()

    # Get the directory and name of the .py file
    py_dirname = os.path.abspath(os.path.dirname(sys.argv[0]))
    py_filename = os.path.basename(__file__)

    # Change to the directory containing the script
    os.chdir(py_dirname)

    # Create a new Python script with the entered text
    with open("Arduino_script.py", "w") as f:
        f.write("import serial.tools.list_ports\n")
        f.write("import serial\n")
        f.write("import time\n")
        f.write("import tkinter as tk\n")
        f.write("import ctypes\n")
        f.write("import winsound\n")
        f.write("\n")
        f.write("# Define the expected response from the Arduino\n")
        f.write(f'EXPECTED_RESPONSE = "{title1}"\n\n')
        f.write("\n")
        f.write("# Define the path to the Windows sounds\n")
        f.write("SOUND_PATH_SUCCESS = 'C:\\\\Windows\\\\Media\\\\tada.wav'\n")
        f.write("SOUND_PATH_FAIL = 'C:\\\\Windows\\\\Media\\\\Windows Hardware Fail.wav'\n")
        f.write("\n")
        f.write("def find_arduino():\n")
        f.write("    # Loop through all available COM ports and try to connect to the Arduino\n")
        f.write("    for port in serial.tools.list_ports.comports():\n")
        f.write("        try:\n")
        f.write(f'            ser = serial.Serial(port.device, baudrate={title4}, timeout=1)\n')
        f.write("            # Send some data to the Arduino\n")
        f.write("            ser.write(b'Hello from Python!')\n")
        f.write("            time.sleep(2) # Wait for 2 seconds for the Arduino to respond\n")
        f.write("            # Read the response from the Arduino\n")
        f.write("            response = ser.readline().decode().strip()\n")
        f.write("            if EXPECTED_RESPONSE in response:\n")
        f.write("                # Do something with the connected Arduino here\n")
        f.write("                ser.close()\n")
        f.write("                return port.device, True\n")
        f.write("            else:\n")
        f.write("                # Response doesn't match, close the port and try the next one\n")
        f.write("                ser.close()\n")
        f.write("        except (OSError, serial.SerialException):\n")
        f.write("            # Couldn't connect to the port, try the next one\n")
        f.write("            pass\n")
        f.write("    return None, False\n")
        f.write("\n")
        f.write("def on_button_click():\n")
        f.write("    port, success = find_arduino()\n")
        f.write("    if success:\n")
        f.write(f'        label.config(text=f"{title2} found on port: {{port}}", font=("Arial", 16))\n')
        f.write("        winsound.PlaySound(SOUND_PATH_SUCCESS, winsound.SND_ASYNC)\n")
        f.write("        # Do something with the connected Arduino here\n")
        f.write("    else:\n")
        f.write(f'        label.config(text=f"{title3}", font=("Arial", 16))\n')
        f.write("        winsound.PlaySound(SOUND_PATH_FAIL, winsound.SND_ASYNC)\n")
        f.write("\n")
        f.write("# Create the main window\n")
        f.write("root = tk.Tk()\n")
        f.write("root.title('What is my COM Port?')\n")
        f.write("\n")
        f.write("# Set the window size\n")
        f.write("root.geometry('600x150')\n\n")
        
        f.write("# Hide the command prompt window\n")
        f.write("import ctypes\n")
        f.write("ctypes.windll.user32.ShowWindow(ctypes.windll.kernel32.GetConsoleWindow(), 0)\n\n")
        
        f.write("# Create a label to display the result\n")
        f.write("label = tk.Label(root, text='', font=('Arial', 16))\n")
        f.write("label.pack()\n\n")
               
        f.write("button = tk.Button(root, text='Search', font=('Arial', 20), bg='#4CAF50', fg='white', command=on_button_click)\n")
        f.write("button.config(width=10, height=1)\n")
        f.write("button.pack(pady=10)\n\n")
        
        f.write("# Start the main event loop\n")
        f.write("root.mainloop()\n")

    # Run the PyInstaller command with the --onefile option
    subprocess.run(['pyinstaller', '--onefile', 'Arduino_script.py'])

    # Delete the Python script
    os.remove('Arduino_script.py')
    os.remove('Arduino_script.spec')

    # Remove the 'build' folder and its contents
    build_folder = os.path.join(os.path.abspath(os.path.dirname(sys.argv[0])), 'build')
    if os.path.exists(build_folder):
        import shutil
        shutil.rmtree(build_folder)

    # Close the window
    window.destroy()

# Create the submit button
submit_button = tk.Button(window, text='Create Exe', command=create_exe)
submit_button.pack()

# Start the main event loop
window.mainloop()
